==> zzyj-financeintegration-api-3.0.0-20250912.041917-125-sources.jar: com/ejianc/business/financeintegration/PMSalary/hystrix/PMSalarySystemHystrix.java <==
package com.ejianc.business.financeintegration.PMSalary.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.financeintegration.PMPayApply.api.IPMSalaryPayApplyApi;
import com.ejianc.business.financeintegration.PMPayApply.vo.PMSalaryPayApplyVO;
import com.ejianc.business.financeintegration.PMSalary.api.IPMSalarySystemApi;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzDetailVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMSbgjjgsVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

@Component
public class PMSalarySystemHystrix implements IPMSalarySystemApi {


    @Override
    public CommonResponse<PMSbgjjgsVO> sbTakeEffect(List<PMSbgjjgsVO> vo) {
        return null;
    }

    @Override
    public CommonResponse<PMGzVO> salaryAbandonOrClose(PMGzVO vo) {
        return null;
    }


    @Override
    public CommonResponse<PMGzVO> salaryTakeEffect(List<PMGzVO> vo) {
        return null;
    }

    @Override
    public CommonResponse<JSONObject> queryList(QueryParam param) {
        return null;
    }

    @Override
    public CommonResponse<JSONObject> queryGZList(QueryParam param) {
        return null;
    }

    @Override
    public CommonResponse<JSONObject> querySalaryDetailList(QueryParam param) {
        return null;
    }

    @Override
    public CommonResponse<JSONObject> changeSalaryDetailState(List<String> vo) {
        return null;
    }
}

==> zzyj-financeintegration-api-3.0.0-20251124.033818-132-sources.jar: com/ejianc/business/financeintegration/PMSalary/hystrix/PMSalarySystemHystrix.java <==
package com.ejianc.business.financeintegration.PMSalary.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.financeintegration.PMPayApply.api.IPMSalaryPayApplyApi;
import com.ejianc.business.financeintegration.PMPayApply.vo.PMSalaryPayApplyVO;
import com.ejianc.business.financeintegration.PMSalary.api.IPMSalarySystemApi;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzDetailVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMSbgjjgsVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

@Component
public class PMSalarySystemHystrix implements IPMSalarySystemApi {


    @Override
    public CommonResponse<PMSbgjjgsVO> sbTakeEffect(List<PMSbgjjgsVO> vo) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }

    @Override
    public CommonResponse<PMGzVO> salaryAbandonOrClose(PMGzVO vo) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }


    @Override
    public CommonResponse<PMGzVO> salaryTakeEffect(List<PMGzVO> vo) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }

    @Override
    public CommonResponse<JSONObject> queryList(QueryParam param) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }

    @Override
    public CommonResponse<JSONObject> queryGZList(QueryParam param) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }

    @Override
    public CommonResponse<JSONObject> querySalaryDetailList(QueryParam param) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }

    @Override
    public CommonResponse<JSONObject> changeSalaryDetailState(List<String> vo) {
        return CommonResponse.error("服务器开小差了，请重试！");
    }
}
